package cn.estsh.i3plus.pojo.wms.bean;

import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.Transient;

/**
 * @Description : 库位表
 * @Reference :
 * @Author : jimmy.zeng
 * @CreateDate : 2018-11-07 10:35
 * @Modify:
 **/
@Data
@Entity
@Table(name = "WMS_LOCATE")
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Api(value = "库位表", description = "库位表")
public class WmsLocate extends BaseBean {

    private static final long serialVersionUID = -8425904594036746967L;
    @Column(name = "LOCATE_NO")
    @ApiParam(value = "库位代码")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.TEXT)
    private String locateNo;

    @Column(name = "LOCATE_NAME")
    @ApiParam(value = "库位名称")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.TEXT)
    private String locateName;

    /**
     * 库位类型:10=收货库,20=基础库,30=机动库,40=组合库,50=线边库,60=NC库，70=溢料,80=在途库位,90=器具库
     */
    @Column(name = "LOCATE_TYPE")
    @ApiParam(value = "库位类型")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.SELECT, entityName = "LOCATE_TYPE")
    private Integer locateType;

    @Column(name = "WH_NO")
    @ApiParam(value = "仓库代码")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.LIST, isRequire = 2,entityName="cn.estsh.i3plus.pojo.wms.bean.WareHouse",
            searchColumnName = "code,name",listColumnName = "code,name", explicitColumnName = "code")
    private String whNo;

    @Column(name = "ZONE_NO")
    @ApiParam(value = "存储区代码")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.LIST, isRequire = 2,entityName="cn.estsh.i3plus.pojo.wms.bean.WmsZones",
            searchColumnName = "zoneNo,zoneName",listColumnName = "zoneNo,zoneName", explicitColumnName = "zoneNo")
    private String zoneNo;

    @Column(name = "FURNITURE_NO")
    @ApiParam(value = "家具代码")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.TEXT, isRequire = 2)
    private String furnitureNo;

    @Column(name = "X")
    @ApiParam(value = "X", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer x;

    @Column(name = "Y")
    @ApiParam(value = "Y", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer y;

    @Column(name = "Z")
    @ApiParam(value = "Z", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer z;

    @Column(name = "LC_LENGTH")
    @ApiParam(value = "长")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer lcLength;

    @Column(name = "LC_WIDTH")
    @ApiParam(value = "宽")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer lcWidth;

    @Column(name = "LC_HEIGHT")
    @ApiParam(value = "高")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer lcHeight;

    @Column(name = "SEQ")
    @ApiParam(value = "序号", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer seq;

    @Column(name = "STATUS")
    @ApiParam(value = "库位状态", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, entityName = "LOCATE_STATUS")
    private Integer status;

    @Column(name = "MAX_PACKAGE_QTY")
    @ApiParam(value = "最大包装数量", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer maxPackageQty;

    @Column(name = "MAX_PART_QTY", columnDefinition = "decimal(18,8)")
    @ApiParam(value = "最大零件数量", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Double maxPartQty;

    @Column(name = "STOCK_UNIT")
    @ApiParam(value = "存放单位")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.TEXT, isRequire = 2)
    private String stockUnit;

    @Column(name = "LINE_CODE")
    @ApiParam(value = "生产线")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.TEXT, isRequire = 2)
    private String lineCode;

    @Column(name = "BOX_QTY")
    @ApiParam(value = "箱数", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Integer boxQty;

    @Column(name = "PART_QTY", columnDefinition = "decimal(18,8)")
    @ApiParam(value = "零件数", example = "-1")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    private Double partQty;

    @Column(name = "ENCRYPTION_NO")
    @ApiParam(value = "加密编码")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.TEXT, isRequire = 2)
    private String encryptionNo;

    @Column(name = "LAST_CS_TIME")
    @ApiParam(value = "末次盘点时间")
    @DynamicField(webFieldType = WmsEnumUtil.FIELD_TYPE.DATETIME, isRequire = 2)
    private String lastCsTime;

    @Column(name = "POSITION")
    @ApiParam(value = "三维位置")
    private String position;

    // 导入用
    @ApiParam(value = "工厂")
    @Transient
    private String factory;

    @Transient
    @ApiParam(value = "入库箱数", example = "-1")
    private Integer destBoxQty;

    @Transient
    @ApiParam(value = "错误信息", example = "-1")
    private String errorMsg;

    @Transient
    @ApiParam(value = "末次盘点开始时间")
    private String lastCsTimeStart ;

    @Transient
    @ApiParam(value = "末次盘点结束时间")
    private String lastCsTimeEnd;

    @Transient
    @ApiParam(value = "库位数组集")
    private String[] locateNoArr;

    @Transient
    @ApiParam(value = "移动频次")
    private Integer frequency;

    @Transient
    @ApiParam(value = "库龄")
    private String age;

    public WmsLocate() {
    }

    public WmsLocate(String locateNo,Integer destBoxQty) {
        this.locateNo = locateNo;
        this.destBoxQty = destBoxQty;
    }

    public WmsLocate(Integer boxQty ,  Double partQty,String locateNo){
        this.boxQty=boxQty;
        this.partQty=partQty;
        this.locateNo=locateNo;
    }
    public WmsLocate(String locateNo,Integer frequency,String organizeCode,
                     String whNo,String zoneNo,String furnitureNo,
                     Integer x,Integer y,Integer z){
        this.locateNo=locateNo;
        this.frequency=frequency;
        this.organizeCode=organizeCode;
        this.whNo=whNo;
        this.zoneNo=zoneNo;
        this.furnitureNo=furnitureNo;
        this.x=x;
        this.y=y;
        this.z=z;
    }
    public WmsLocate(String locateNo,String age,String organizeCode,
                     String whNo,String zoneNo,String furnitureNo,
                     Integer x,Integer y,Integer z){
        this.locateNo=locateNo;
        this.age=age;
        this.organizeCode=organizeCode;
        this.whNo=whNo;
        this.zoneNo=zoneNo;
        this.furnitureNo=furnitureNo;
        this.x=x;
        this.y=y;
        this.z=z;
    }

    public Integer getMaxPackageQty() {
        return this.maxPackageQty == null ? 0 : this.maxPackageQty.intValue();
    }

    public Double getMaxPartQty() {
        return this.maxPartQty == null ? 0 : this.maxPartQty.doubleValue();
    }

    public Integer getBoxQty() {
        return this.boxQty == null ? 0 : this.boxQty.intValue();
    }

    public Double getPartQty() {
        return this.partQty == null ? 0 : this.partQty.doubleValue();
    }

    public Integer getLocateType() {
        return this.locateType== null ? 0 : this.locateType.intValue();
    }

    public Integer getFrequencyVal() {
        return this.frequency == null ? 0 : this.frequency.intValue();
    }

    public Integer getLcLengthVal() {
        return this.lcLength == null ? 0 : this.lcLength.intValue();
    }
    public Integer getLcWidthVal() {
        return this.lcWidth == null ? 0 : this.lcWidth.intValue();
    }
    public Integer getLcHeightVal() {
        return this.lcHeight == null ? 0 : this.lcHeight.intValue();
    }

    public Integer getXVal() {
        return this.x == null ? 0 : this.x.intValue();
    }
    public Integer getYVal() {
        return this.y == null ? 0 : this.y.intValue();
    }
    public Integer getZVal() {
        return this.z == null ? 0 : this.z.intValue();
    }


}
